# Scanning for software snippets

**ts-scan** also supports to scan for known algorithm snippets. Therefor **ts-scan** can apply **ts-deepscan** which extends **SCANOSS** fingerprinting mechanism. Read here, how you may apply this to identify already used or re-used code snippets. Especially in the era of KI-driven development, code has a tendency to having been copied from somewhere...

 (tbc...)



> [!NOTE] 
>
> Our SCANOSS integration provides two sorts of usage. The first is the default option, using the public knowledge base. The second is to use your private API key and access either a private endpoint or the commercial subscription. SCANOSS does not provide different datasets. The public will be updated in different timelines than the pcomemrcial one. But the major difference are the API limits. The burst rate is much higher in the subscriptions than in the public API. [Reach out](https://www.trustsource.io/contact) to learn more, in case you are interested.  